/* Copyright Statement:
 *
 * This software/firmware and related documentation ("AutoChips Software") are
 * protected under relevant copyright laws. The information contained herein is
 * confidential and proprietary to AutoChips Inc. and/or its licensors. Without
 * the prior written permission of AutoChips inc. and/or its licensors, any
 * reproduction, modification, use or disclosure of AutoChips Software, and
 * information contained herein, in whole or in part, shall be strictly
 * prohibited.
 *
 * AutoChips Inc. (C) 2016. All rights reserved.
 *
 * BY OPENING THIS FILE, RECEIVER HEREBY UNEQUIVOCALLY ACKNOWLEDGES AND AGREES
 * THAT THE SOFTWARE/FIRMWARE AND ITS DOCUMENTATIONS ("AUTOCHIPS SOFTWARE")
 * RECEIVED FROM AUTOCHIPS AND/OR ITS REPRESENTATIVES ARE PROVIDED TO RECEIVER
 * ON AN "AS-IS" BASIS ONLY. AUTOCHIPS EXPRESSLY DISCLAIMS ANY AND ALL
 * WARRANTIES, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR
 * NONINFRINGEMENT. NEITHER DOES AUTOCHIPS PROVIDE ANY WARRANTY WHATSOEVER WITH
 * RESPECT TO THE SOFTWARE OF ANY THIRD PARTY WHICH MAY BE USED BY,
 * INCORPORATED IN, OR SUPPLIED WITH THE AUTOCHIPS SOFTWARE, AND RECEIVER AGREES
 * TO LOOK ONLY TO SUCH THIRD PARTY FOR ANY WARRANTY CLAIM RELATING THERETO.
 * RECEIVER EXPRESSLY ACKNOWLEDGES THAT IT IS RECEIVER'S SOLE RESPONSIBILITY TO
 * OBTAIN FROM ANY THIRD PARTY ALL PROPER LICENSES CONTAINED IN AUTOCHIPS
 * SOFTWARE. AUTOCHIPS SHALL ALSO NOT BE RESPONSIBLE FOR ANY AUTOCHIPS SOFTWARE
 * RELEASES MADE TO RECEIVER'S SPECIFICATION OR TO CONFORM TO A PARTICULAR
 * STANDARD OR OPEN FORUM. RECEIVER'S SOLE AND EXCLUSIVE REMEDY AND AUTOCHIPS'S
 * ENTIRE AND CUMULATIVE LIABILITY WITH RESPECT TO THE AUTOCHIPS SOFTWARE
 * RELEASED HEREUNDER WILL BE, AT AUTOCHIPS'S OPTION, TO REVISE OR REPLACE THE
 * AUTOCHIPS SOFTWARE AT ISSUE, OR REFUND ANY SOFTWARE LICENSE FEES OR SERVICE
 * CHARGE PAID BY RECEIVER TO AUTOCHIPS FOR SUCH AUTOCHIPS SOFTWARE AT ISSUE.
 */

#include "timer_sample.h"


/* timer3中断计数 */
uint16_t g_timer3Count = 0;


/**
* @param[in] device: TIMER_CHANNEL3
* @param[in] wpara: TIMER_GetTimeoutFlag(TIMER_CHANNEL3)
                    Flag在CMSIS中已被清零,不需再清零.
                    wpara可用来判断.
* @param[in] lpara: 0
*
* @return none
*
* @brief TIMER3 CallBack
*/
void TIM3_Task(void *device, uint32_t wpara, uint32_t lpara)
{
    g_timer3Count++;
    LED2_TOGGLE
    printf("g_timer3Count = %d\r\n",g_timer3Count);
}

/**
*
* @param[in] none
*
* @return none
*
* @brief Timer_Init
*        TIMER_CHANNEL1定时1ms,
*        TIMER_CHANNEL2链接到TIMER_CHANNEL1上,定时1s
*        TIMER_CHANNEL3链接到TIMER_CHANNEL2上,定时60s
*        注意:在链接模式中，TIMER_CHANNEL0不能链接到其他timer上
*/
void Timer_Init(void)
{
    /* TIMER channel configuration structure */
    TIMER_ConfigType  timerConfig1;
    TIMER_ConfigType  timerConfig2;
    TIMER_ConfigType  timerConfig3;

    /* timerConfig结构体数据清零 */
    memset(&timerConfig1, 0, sizeof(timerConfig1));
    memset(&timerConfig2, 0, sizeof(timerConfig2));
    memset(&timerConfig3, 0, sizeof(timerConfig3));

    /* configure TIMER channel 1 */
    timerConfig1.periodValue      = TIMER_CHANNEL1_PERIOD_VALUE;    /* TIMER_CHANNEL1 period value */
    timerConfig1.linkModeEn       = DISABLE;          /* 禁能链接模式 */
    timerConfig1.interruptEn      = DISABLE;          /* 禁能中断 */   
    timerConfig1.timerEn          = ENABLE;           /* 使能TIMER_CHANNEL1 */
    timerConfig1.callBack         = NULL;             /* TIMER_CHANNEL1不设置回调函数 */
    TIMER_Init(TIMER_CHANNEL1, &timerConfig1);        /* 设置TIMER_CHANNEL1初始化 */  

    /* configure TIMER channel 2 */
    timerConfig2.periodValue      = TIMER_CHANNEL2_PERIOD_VALUE;    /* TIMER_CHANNEL2 period value */
    timerConfig2.linkModeEn       = ENABLE;           /* 使能链接模式 */
    timerConfig2.interruptEn      = DISABLE;          /* 禁能中断 */   
    timerConfig2.timerEn          = ENABLE;           /* 使能TIMER_CHANNEL2 */
    timerConfig2.callBack         = NULL;             /* TIMER_CHANNEL2不设置回调函数 */
    TIMER_Init(TIMER_CHANNEL2, &timerConfig2);        /* 设置TIMER_CHANNEL2初始化 */ 

    /* configure TIMER channel 3 */
    timerConfig3.periodValue      = TIMER_CHANNEL3_PERIOD_VALUE;    /* TIMER_CHANNEL3 period value */
    timerConfig3.linkModeEn       = ENABLE;           /* 使能链接模式 */
    timerConfig3.interruptEn      = ENABLE;           /* 使能中断 */   
    timerConfig3.timerEn          = ENABLE;           /* 使能TIMER_CHANNEL3 */
    timerConfig3.callBack         = TIM3_Task;        /* 设置TIMER_CHANNEL3回调函数 */
    TIMER_Init(TIMER_CHANNEL3, &timerConfig3);        /* 设置TIMER_CHANNEL3初始化 */      
}

/**
*
* @param[in] none
*
* @return	 none
*
* @brief  初始化LED引脚
*/
void GPIO_LedInit(void)
{
    /* PIN脚为gpio功能 */
    GPIO_SetFunc(LED2_PORT, LED2_PIN, GPIO_FUN0);

    /* 设置PIN脚为GPIO输出 */
    GPIO_SetDir(LED2_PORT, LED2_PIN, GPIO_OUT);
}

/**
*
* @param[in] none
*
* @return none
*
* @brief Timer_Link_Mode
* 
*/
void Timer_Link_Mode(void)
{
    Timer_Init();
    GPIO_LedInit();
}
